# WidgetOptionsMarkdown


## Properties

Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**body** | **str** |  | [optional] 

## Example

```python
from src.client.generated.models.widget_options_markdown import WidgetOptionsMarkdown

# TODO update the JSON string below
json = "{}"
# create an instance of WidgetOptionsMarkdown from a JSON string
widget_options_markdown_instance = WidgetOptionsMarkdown.from_json(json)
# print the JSON string representation of the object
print(WidgetOptionsMarkdown.to_json())

# convert the object into a dict
widget_options_markdown_dict = widget_options_markdown_instance.to_dict()
# create an instance of WidgetOptionsMarkdown from a dict
widget_options_markdown_from_dict = WidgetOptionsMarkdown.from_dict(widget_options_markdown_dict)
```
[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


